.. currentmodule:: cratermaker

.. _user-guide:

###########
User Guide
###########

This section provides an overview of the components of the Cratermaker package, with several examples to demonstrate how each component works.


.. toctree::
   :maxdepth: 2

   installation
   components-overview 
   simulation   
   visualizing

